package cn.com.infosec.asn1.isismtt.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.x509.GeneralName;
import java.util.Enumeration;

public class AdmissionSyntax extends ASN1Encodable {
   private GeneralName admissionAuthority;
   private ASN1Sequence contentsOfAdmissions;

   public static AdmissionSyntax getInstance(Object obj) {
      if (obj != null && !(obj instanceof AdmissionSyntax)) {
         if (obj instanceof ASN1Sequence) {
            return new AdmissionSyntax((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
         }
      } else {
         return (AdmissionSyntax)obj;
      }
   }

   private AdmissionSyntax(ASN1Sequence seq) {
      int var2;
      if ((var2 = seq.size()) != 1) {
         if (var2 != 2) {
            throw new IllegalArgumentException("Bad sequence size: " + seq.size());
         }

         this.admissionAuthority = GeneralName.getInstance(seq.getObjectAt(0));
         this.contentsOfAdmissions = ASN1Sequence.getInstance(seq.getObjectAt(1));
      } else {
         this.contentsOfAdmissions = ASN1Sequence.getInstance(seq.getObjectAt(0));
      }

   }

   public AdmissionSyntax(GeneralName admissionAuthority, ASN1Sequence contentsOfAdmissions) {
      this.admissionAuthority = admissionAuthority;
      this.contentsOfAdmissions = contentsOfAdmissions;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      GeneralName var2;
      if ((var2 = this.admissionAuthority) != null) {
         var1.add(var2);
      }

      var1.add(this.contentsOfAdmissions);
      return new DERSequence(var1);
   }

   public GeneralName getAdmissionAuthority() {
      return this.admissionAuthority;
   }

   public Admissions[] getContentsOfAdmissions() {
      Admissions[] var3 = new Admissions[this.contentsOfAdmissions.size()];
      int var1 = 0;

      for(Enumeration var2 = this.contentsOfAdmissions.getObjects(); var2.hasMoreElements(); var3[var1++] = Admissions.getInstance(var2.nextElement())) {
      }

      return var3;
   }
}
